"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import unittest

import cryptoapis
from cryptoapis.api.informative_api import InformativeApi  # noqa: E501


class TestInformativeApi(unittest.TestCase):
    """InformativeApi unit test stubs"""

    def setUp(self):
        self.api = InformativeApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_wallet_asset_details(self):
        """Test case for get_wallet_asset_details

        Get Wallet Asset Details  # noqa: E501
        """
        pass

    def test_list_receiving_addresses(self):
        """Test case for list_receiving_addresses

        List Receiving Addresses  # noqa: E501
        """
        pass

    def test_list_supported_tokens(self):
        """Test case for list_supported_tokens

        List Supported Tokens  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
