"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.list_xrp_ripple_transactions_by_block_height_ri_fee import ListXRPRippleTransactionsByBlockHeightRIFee
from cryptoapis.model.list_xrp_ripple_transactions_by_block_height_ri_offer import ListXRPRippleTransactionsByBlockHeightRIOffer
from cryptoapis.model.list_xrp_ripple_transactions_by_block_height_ri_receive import ListXRPRippleTransactionsByBlockHeightRIReceive
from cryptoapis.model.list_xrp_ripple_transactions_by_block_height_ri_recipients import ListXRPRippleTransactionsByBlockHeightRIRecipients
from cryptoapis.model.list_xrp_ripple_transactions_by_block_height_ri_senders import ListXRPRippleTransactionsByBlockHeightRISenders
from cryptoapis.model.list_xrp_ripple_transactions_by_block_height_ri_value import ListXRPRippleTransactionsByBlockHeightRIValue
globals()['ListXRPRippleTransactionsByBlockHeightRIFee'] = ListXRPRippleTransactionsByBlockHeightRIFee
globals()['ListXRPRippleTransactionsByBlockHeightRIOffer'] = ListXRPRippleTransactionsByBlockHeightRIOffer
globals()['ListXRPRippleTransactionsByBlockHeightRIReceive'] = ListXRPRippleTransactionsByBlockHeightRIReceive
globals()['ListXRPRippleTransactionsByBlockHeightRIRecipients'] = ListXRPRippleTransactionsByBlockHeightRIRecipients
globals()['ListXRPRippleTransactionsByBlockHeightRISenders'] = ListXRPRippleTransactionsByBlockHeightRISenders
globals()['ListXRPRippleTransactionsByBlockHeightRIValue'] = ListXRPRippleTransactionsByBlockHeightRIValue
from cryptoapis.model.list_xrp_ripple_transactions_by_block_height_ri import ListXRPRippleTransactionsByBlockHeightRI


class TestListXRPRippleTransactionsByBlockHeightRI(unittest.TestCase):
    """ListXRPRippleTransactionsByBlockHeightRI unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListXRPRippleTransactionsByBlockHeightRI(self):
        """Test ListXRPRippleTransactionsByBlockHeightRI"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListXRPRippleTransactionsByBlockHeightRI()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
