"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.list_transactions_by_address_ribsb import ListTransactionsByAddressRIBSB
from cryptoapis.model.list_transactions_by_address_ribsbc import ListTransactionsByAddressRIBSBC
from cryptoapis.model.list_transactions_by_address_ribsd import ListTransactionsByAddressRIBSD
from cryptoapis.model.list_transactions_by_address_ribsd2 import ListTransactionsByAddressRIBSD2
from cryptoapis.model.list_transactions_by_address_ribsd2_vin import ListTransactionsByAddressRIBSD2Vin
from cryptoapis.model.list_transactions_by_address_ribsd2_vout import ListTransactionsByAddressRIBSD2Vout
from cryptoapis.model.list_transactions_by_address_ribse import ListTransactionsByAddressRIBSE
from cryptoapis.model.list_transactions_by_address_ribse_gas_price import ListTransactionsByAddressRIBSEGasPrice
from cryptoapis.model.list_transactions_by_address_ribsec import ListTransactionsByAddressRIBSEC
from cryptoapis.model.list_transactions_by_address_ribsl import ListTransactionsByAddressRIBSL
globals()['ListTransactionsByAddressRIBSB'] = ListTransactionsByAddressRIBSB
globals()['ListTransactionsByAddressRIBSBC'] = ListTransactionsByAddressRIBSBC
globals()['ListTransactionsByAddressRIBSD'] = ListTransactionsByAddressRIBSD
globals()['ListTransactionsByAddressRIBSD2'] = ListTransactionsByAddressRIBSD2
globals()['ListTransactionsByAddressRIBSD2Vin'] = ListTransactionsByAddressRIBSD2Vin
globals()['ListTransactionsByAddressRIBSD2Vout'] = ListTransactionsByAddressRIBSD2Vout
globals()['ListTransactionsByAddressRIBSE'] = ListTransactionsByAddressRIBSE
globals()['ListTransactionsByAddressRIBSEC'] = ListTransactionsByAddressRIBSEC
globals()['ListTransactionsByAddressRIBSEGasPrice'] = ListTransactionsByAddressRIBSEGasPrice
globals()['ListTransactionsByAddressRIBSL'] = ListTransactionsByAddressRIBSL
from cryptoapis.model.list_transactions_by_address_ribs import ListTransactionsByAddressRIBS


class TestListTransactionsByAddressRIBS(unittest.TestCase):
    """ListTransactionsByAddressRIBS unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListTransactionsByAddressRIBS(self):
        """Test ListTransactionsByAddressRIBS"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListTransactionsByAddressRIBS()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
