"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_xrp_ripple_transaction_details_by_transaction_idri_fee import GetXRPRippleTransactionDetailsByTransactionIDRIFee
from cryptoapis.model.get_xrp_ripple_transaction_details_by_transaction_idri_offer import GetXRPRippleTransactionDetailsByTransactionIDRIOffer
from cryptoapis.model.get_xrp_ripple_transaction_details_by_transaction_idri_receive import GetXRPRippleTransactionDetailsByTransactionIDRIReceive
from cryptoapis.model.get_xrp_ripple_transaction_details_by_transaction_idri_recipients import GetXRPRippleTransactionDetailsByTransactionIDRIRecipients
from cryptoapis.model.get_xrp_ripple_transaction_details_by_transaction_idri_senders import GetXRPRippleTransactionDetailsByTransactionIDRISenders
from cryptoapis.model.get_xrp_ripple_transaction_details_by_transaction_idri_value import GetXRPRippleTransactionDetailsByTransactionIDRIValue
globals()['GetXRPRippleTransactionDetailsByTransactionIDRIFee'] = GetXRPRippleTransactionDetailsByTransactionIDRIFee
globals()['GetXRPRippleTransactionDetailsByTransactionIDRIOffer'] = GetXRPRippleTransactionDetailsByTransactionIDRIOffer
globals()['GetXRPRippleTransactionDetailsByTransactionIDRIReceive'] = GetXRPRippleTransactionDetailsByTransactionIDRIReceive
globals()['GetXRPRippleTransactionDetailsByTransactionIDRIRecipients'] = GetXRPRippleTransactionDetailsByTransactionIDRIRecipients
globals()['GetXRPRippleTransactionDetailsByTransactionIDRISenders'] = GetXRPRippleTransactionDetailsByTransactionIDRISenders
globals()['GetXRPRippleTransactionDetailsByTransactionIDRIValue'] = GetXRPRippleTransactionDetailsByTransactionIDRIValue
from cryptoapis.model.get_xrp_ripple_transaction_details_by_transaction_idri import GetXRPRippleTransactionDetailsByTransactionIDRI


class TestGetXRPRippleTransactionDetailsByTransactionIDRI(unittest.TestCase):
    """GetXRPRippleTransactionDetailsByTransactionIDRI unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetXRPRippleTransactionDetailsByTransactionIDRI(self):
        """Test GetXRPRippleTransactionDetailsByTransactionIDRI"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetXRPRippleTransactionDetailsByTransactionIDRI()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
