"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import unittest

import cryptoapis
from cryptoapis.api.create_subscriptions_for_api import CreateSubscriptionsForApi  # noqa: E501


class TestCreateSubscriptionsForApi(unittest.TestCase):
    """CreateSubscriptionsForApi unit test stubs"""

    def setUp(self):
        self.api = CreateSubscriptionsForApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_mined_transaction(self):
        """Test case for mined_transaction

        Mined transaction  # noqa: E501
        """
        pass

    def test_new_block(self):
        """Test case for new_block

        New Block  # noqa: E501
        """
        pass

    def test_new_confirmed_coins_transactions(self):
        """Test case for new_confirmed_coins_transactions

        New confirmed coins transactions  # noqa: E501
        """
        pass

    def test_new_confirmed_coins_transactions_and_each_confirmation(self):
        """Test case for new_confirmed_coins_transactions_and_each_confirmation

        New confirmed coins transactions and each confirmation  # noqa: E501
        """
        pass

    def test_new_confirmed_internal_transactions(self):
        """Test case for new_confirmed_internal_transactions

        New confirmed internal transactions  # noqa: E501
        """
        pass

    def test_new_confirmed_internal_transactions_and_each_confirmation(self):
        """Test case for new_confirmed_internal_transactions_and_each_confirmation

        New confirmed internal transactions and each confirmation  # noqa: E501
        """
        pass

    def test_new_confirmed_tokens_transactions(self):
        """Test case for new_confirmed_tokens_transactions

        New confirmed tokens transactions  # noqa: E501
        """
        pass

    def test_new_confirmed_tokens_transactions_and_each_confirmation(self):
        """Test case for new_confirmed_tokens_transactions_and_each_confirmation

        New confirmed tokens transactions and each confirmation  # noqa: E501
        """
        pass

    def test_new_unconfirmed_coins_transactions(self):
        """Test case for new_unconfirmed_coins_transactions

        New unconfirmed coins transactions  # noqa: E501
        """
        pass

    def test_new_unconfirmed_tokens_transactions(self):
        """Test case for new_unconfirmed_tokens_transactions

        New unconfirmed tokens transactions  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
