"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_block_details_by_block_hash_ribsb import GetBlockDetailsByBlockHashRIBSB
from cryptoapis.model.get_block_details_by_block_hash_ribsbc import GetBlockDetailsByBlockHashRIBSBC
from cryptoapis.model.get_block_details_by_block_hash_ribsd import GetBlockDetailsByBlockHashRIBSD
from cryptoapis.model.get_block_details_by_block_hash_ribsd2 import GetBlockDetailsByBlockHashRIBSD2
from cryptoapis.model.get_block_details_by_block_hash_ribse import GetBlockDetailsByBlockHashRIBSE
from cryptoapis.model.get_block_details_by_block_hash_ribsec import GetBlockDetailsByBlockHashRIBSEC
from cryptoapis.model.get_block_details_by_block_hash_ribsl import GetBlockDetailsByBlockHashRIBSL
globals()['GetBlockDetailsByBlockHashRIBSB'] = GetBlockDetailsByBlockHashRIBSB
globals()['GetBlockDetailsByBlockHashRIBSBC'] = GetBlockDetailsByBlockHashRIBSBC
globals()['GetBlockDetailsByBlockHashRIBSD'] = GetBlockDetailsByBlockHashRIBSD
globals()['GetBlockDetailsByBlockHashRIBSD2'] = GetBlockDetailsByBlockHashRIBSD2
globals()['GetBlockDetailsByBlockHashRIBSE'] = GetBlockDetailsByBlockHashRIBSE
globals()['GetBlockDetailsByBlockHashRIBSEC'] = GetBlockDetailsByBlockHashRIBSEC
globals()['GetBlockDetailsByBlockHashRIBSL'] = GetBlockDetailsByBlockHashRIBSL
from cryptoapis.model.get_block_details_by_block_hash_ribs import GetBlockDetailsByBlockHashRIBS


class TestGetBlockDetailsByBlockHashRIBS(unittest.TestCase):
    """GetBlockDetailsByBlockHashRIBS unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetBlockDetailsByBlockHashRIBS(self):
        """Test GetBlockDetailsByBlockHashRIBS"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetBlockDetailsByBlockHashRIBS()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
