"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.create_tokens_transaction_request_from_address_ri_recipients import CreateTokensTransactionRequestFromAddressRIRecipients
from cryptoapis.model.create_tokens_transaction_request_from_address_ri_senders import CreateTokensTransactionRequestFromAddressRISenders
from cryptoapis.model.create_tokens_transaction_request_from_address_ri_token_type_specific_data import CreateTokensTransactionRequestFromAddressRITokenTypeSpecificData
globals()['CreateTokensTransactionRequestFromAddressRIRecipients'] = CreateTokensTransactionRequestFromAddressRIRecipients
globals()['CreateTokensTransactionRequestFromAddressRISenders'] = CreateTokensTransactionRequestFromAddressRISenders
globals()['CreateTokensTransactionRequestFromAddressRITokenTypeSpecificData'] = CreateTokensTransactionRequestFromAddressRITokenTypeSpecificData
from cryptoapis.model.create_tokens_transaction_request_from_address_ri import CreateTokensTransactionRequestFromAddressRI


class TestCreateTokensTransactionRequestFromAddressRI(unittest.TestCase):
    """CreateTokensTransactionRequestFromAddressRI unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCreateTokensTransactionRequestFromAddressRI(self):
        """Test CreateTokensTransactionRequestFromAddressRI"""
        # FIXME: construct object with mandatory attributes with example values
        # model = CreateTokensTransactionRequestFromAddressRI()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
