"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.create_coins_transaction_request_from_wallet_rb_data import CreateCoinsTransactionRequestFromWalletRBData
globals()['CreateCoinsTransactionRequestFromWalletRBData'] = CreateCoinsTransactionRequestFromWalletRBData
from cryptoapis.model.create_coins_transaction_request_from_wallet_rb import CreateCoinsTransactionRequestFromWalletRB


class TestCreateCoinsTransactionRequestFromWalletRB(unittest.TestCase):
    """CreateCoinsTransactionRequestFromWalletRB unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCreateCoinsTransactionRequestFromWalletRB(self):
        """Test CreateCoinsTransactionRequestFromWalletRB"""
        # FIXME: construct object with mandatory attributes with example values
        # model = CreateCoinsTransactionRequestFromWalletRB()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
