# flake8: noqa

"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


__version__ = "1.1.0"

# import ApiClient
from cryptoapis.api_client import ApiClient

# import Configuration
from cryptoapis.configuration import Configuration

# import exceptions
from cryptoapis.exceptions import OpenApiException
from cryptoapis.exceptions import ApiAttributeError
from cryptoapis.exceptions import ApiTypeError
from cryptoapis.exceptions import ApiValueError
from cryptoapis.exceptions import ApiKeyError
from cryptoapis.exceptions import ApiException
