"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_block_details_by_block_height_ribsb import GetBlockDetailsByBlockHeightRIBSB
from cryptoapis.model.get_block_details_by_block_height_ribsbc import GetBlockDetailsByBlockHeightRIBSBC
from cryptoapis.model.get_block_details_by_block_height_ribsd import GetBlockDetailsByBlockHeightRIBSD
from cryptoapis.model.get_block_details_by_block_height_ribsd2 import GetBlockDetailsByBlockHeightRIBSD2
from cryptoapis.model.get_block_details_by_block_height_ribse import GetBlockDetailsByBlockHeightRIBSE
from cryptoapis.model.get_block_details_by_block_height_ribsec import GetBlockDetailsByBlockHeightRIBSEC
from cryptoapis.model.get_block_details_by_block_height_ribsl import GetBlockDetailsByBlockHeightRIBSL
globals()['GetBlockDetailsByBlockHeightRIBSB'] = GetBlockDetailsByBlockHeightRIBSB
globals()['GetBlockDetailsByBlockHeightRIBSBC'] = GetBlockDetailsByBlockHeightRIBSBC
globals()['GetBlockDetailsByBlockHeightRIBSD'] = GetBlockDetailsByBlockHeightRIBSD
globals()['GetBlockDetailsByBlockHeightRIBSD2'] = GetBlockDetailsByBlockHeightRIBSD2
globals()['GetBlockDetailsByBlockHeightRIBSE'] = GetBlockDetailsByBlockHeightRIBSE
globals()['GetBlockDetailsByBlockHeightRIBSEC'] = GetBlockDetailsByBlockHeightRIBSEC
globals()['GetBlockDetailsByBlockHeightRIBSL'] = GetBlockDetailsByBlockHeightRIBSL
from cryptoapis.model.get_block_details_by_block_height_ribs import GetBlockDetailsByBlockHeightRIBS


class TestGetBlockDetailsByBlockHeightRIBS(unittest.TestCase):
    """GetBlockDetailsByBlockHeightRIBS unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetBlockDetailsByBlockHeightRIBS(self):
        """Test GetBlockDetailsByBlockHeightRIBS"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetBlockDetailsByBlockHeightRIBS()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
