"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.list_transactions_by_block_hash_ribsbc_vin import ListTransactionsByBlockHashRIBSBCVin
from cryptoapis.model.list_transactions_by_block_hash_ribsbc_vout import ListTransactionsByBlockHashRIBSBCVout
from cryptoapis.model.list_transactions_by_block_height_ribsb import ListTransactionsByBlockHeightRIBSB
from cryptoapis.model.list_transactions_by_block_height_ribsbc import ListTransactionsByBlockHeightRIBSBC
from cryptoapis.model.list_transactions_by_block_height_ribsd import ListTransactionsByBlockHeightRIBSD
from cryptoapis.model.list_transactions_by_block_height_ribsd2 import ListTransactionsByBlockHeightRIBSD2
from cryptoapis.model.list_transactions_by_block_height_ribse import ListTransactionsByBlockHeightRIBSE
from cryptoapis.model.list_transactions_by_block_height_ribsec import ListTransactionsByBlockHeightRIBSEC
from cryptoapis.model.list_transactions_by_block_height_ribsec_gas_price import ListTransactionsByBlockHeightRIBSECGasPrice
from cryptoapis.model.list_transactions_by_block_height_ribsl import ListTransactionsByBlockHeightRIBSL
globals()['ListTransactionsByBlockHashRIBSBCVin'] = ListTransactionsByBlockHashRIBSBCVin
globals()['ListTransactionsByBlockHashRIBSBCVout'] = ListTransactionsByBlockHashRIBSBCVout
globals()['ListTransactionsByBlockHeightRIBSB'] = ListTransactionsByBlockHeightRIBSB
globals()['ListTransactionsByBlockHeightRIBSBC'] = ListTransactionsByBlockHeightRIBSBC
globals()['ListTransactionsByBlockHeightRIBSD'] = ListTransactionsByBlockHeightRIBSD
globals()['ListTransactionsByBlockHeightRIBSD2'] = ListTransactionsByBlockHeightRIBSD2
globals()['ListTransactionsByBlockHeightRIBSE'] = ListTransactionsByBlockHeightRIBSE
globals()['ListTransactionsByBlockHeightRIBSEC'] = ListTransactionsByBlockHeightRIBSEC
globals()['ListTransactionsByBlockHeightRIBSECGasPrice'] = ListTransactionsByBlockHeightRIBSECGasPrice
globals()['ListTransactionsByBlockHeightRIBSL'] = ListTransactionsByBlockHeightRIBSL
from cryptoapis.model.list_transactions_by_block_height_ribs import ListTransactionsByBlockHeightRIBS


class TestListTransactionsByBlockHeightRIBS(unittest.TestCase):
    """ListTransactionsByBlockHeightRIBS unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListTransactionsByBlockHeightRIBS(self):
        """Test ListTransactionsByBlockHeightRIBS"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListTransactionsByBlockHeightRIBS()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
