"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_zilliqa_transaction_details_by_transaction_idri_fee import GetZilliqaTransactionDetailsByTransactionIDRIFee
from cryptoapis.model.get_zilliqa_transaction_details_by_transaction_idri_recipients import GetZilliqaTransactionDetailsByTransactionIDRIRecipients
from cryptoapis.model.get_zilliqa_transaction_details_by_transaction_idri_senders import GetZilliqaTransactionDetailsByTransactionIDRISenders
globals()['GetZilliqaTransactionDetailsByTransactionIDRIFee'] = GetZilliqaTransactionDetailsByTransactionIDRIFee
globals()['GetZilliqaTransactionDetailsByTransactionIDRIRecipients'] = GetZilliqaTransactionDetailsByTransactionIDRIRecipients
globals()['GetZilliqaTransactionDetailsByTransactionIDRISenders'] = GetZilliqaTransactionDetailsByTransactionIDRISenders
from cryptoapis.model.get_zilliqa_transaction_details_by_transaction_idri import GetZilliqaTransactionDetailsByTransactionIDRI


class TestGetZilliqaTransactionDetailsByTransactionIDRI(unittest.TestCase):
    """GetZilliqaTransactionDetailsByTransactionIDRI unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetZilliqaTransactionDetailsByTransactionIDRI(self):
        """Test GetZilliqaTransactionDetailsByTransactionIDRI"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetZilliqaTransactionDetailsByTransactionIDRI()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
