"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import unittest

import cryptoapis
from cryptoapis.api.utxo_based_api import UTXOBasedApi  # noqa: E501


class TestUTXOBasedApi(unittest.TestCase):
    """UTXOBasedApi unit test stubs"""

    def setUp(self):
        self.api = UTXOBasedApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_hd_wallet__x_pub_y_pub_z_pub_details(self):
        """Test case for get_hd_wallet__x_pub_y_pub_z_pub_details

        Get HD Wallet (xPub, yPub, zPub) Details  # noqa: E501
        """
        pass

    def test_list_hd_wallet__x_pub_y_pub_z_pub_transactions(self):
        """Test case for list_hd_wallet__x_pub_y_pub_z_pub_transactions

        List HD Wallet (xPub, yPub, zPub) Transactions  # noqa: E501
        """
        pass

    def test_sync_hd_wallet__x_pub_y_pub_z_pub(self):
        """Test case for sync_hd_wallet__x_pub_y_pub_z_pub

        Sync HD Wallet (xPub, yPub, zPub)  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
