"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import unittest

import cryptoapis
from cryptoapis.api.automatic_tokens_forwarding_api import AutomaticTokensForwardingApi  # noqa: E501


class TestAutomaticTokensForwardingApi(unittest.TestCase):
    """AutomaticTokensForwardingApi unit test stubs"""

    def setUp(self):
        self.api = AutomaticTokensForwardingApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_tokens_to_existing_from_address(self):
        """Test case for add_tokens_to_existing_from_address

        Add Tokens To Existing fromAddress  # noqa: E501
        """
        pass

    def test_create_automatic_tokens_forwarding(self):
        """Test case for create_automatic_tokens_forwarding

        Create Automatic Tokens Forwarding  # noqa: E501
        """
        pass

    def test_delete_automatic_tokens_forwarding(self):
        """Test case for delete_automatic_tokens_forwarding

        Delete Automatic Tokens Forwarding  # noqa: E501
        """
        pass

    def test_get_fee_address_details(self):
        """Test case for get_fee_address_details

        Get Fee Address Details  # noqa: E501
        """
        pass

    def test_list_tokens_forwarding_automations(self):
        """Test case for list_tokens_forwarding_automations

        List Tokens Forwarding Automations  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
