"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.get_transaction_details_by_transaction_idribsb import GetTransactionDetailsByTransactionIDRIBSB
from cryptoapis.model.get_transaction_details_by_transaction_idribsbc import GetTransactionDetailsByTransactionIDRIBSBC
from cryptoapis.model.get_transaction_details_by_transaction_idribsd import GetTransactionDetailsByTransactionIDRIBSD
from cryptoapis.model.get_transaction_details_by_transaction_idribsd2 import GetTransactionDetailsByTransactionIDRIBSD2
from cryptoapis.model.get_transaction_details_by_transaction_idribsd2_vin import GetTransactionDetailsByTransactionIDRIBSD2Vin
from cryptoapis.model.get_transaction_details_by_transaction_idribsd2_vout import GetTransactionDetailsByTransactionIDRIBSD2Vout
from cryptoapis.model.get_transaction_details_by_transaction_idribse import GetTransactionDetailsByTransactionIDRIBSE
from cryptoapis.model.get_transaction_details_by_transaction_idribsec import GetTransactionDetailsByTransactionIDRIBSEC
from cryptoapis.model.get_transaction_details_by_transaction_idribsec_gas_price import GetTransactionDetailsByTransactionIDRIBSECGasPrice
from cryptoapis.model.get_transaction_details_by_transaction_idribsl import GetTransactionDetailsByTransactionIDRIBSL
globals()['GetTransactionDetailsByTransactionIDRIBSB'] = GetTransactionDetailsByTransactionIDRIBSB
globals()['GetTransactionDetailsByTransactionIDRIBSBC'] = GetTransactionDetailsByTransactionIDRIBSBC
globals()['GetTransactionDetailsByTransactionIDRIBSD'] = GetTransactionDetailsByTransactionIDRIBSD
globals()['GetTransactionDetailsByTransactionIDRIBSD2'] = GetTransactionDetailsByTransactionIDRIBSD2
globals()['GetTransactionDetailsByTransactionIDRIBSD2Vin'] = GetTransactionDetailsByTransactionIDRIBSD2Vin
globals()['GetTransactionDetailsByTransactionIDRIBSD2Vout'] = GetTransactionDetailsByTransactionIDRIBSD2Vout
globals()['GetTransactionDetailsByTransactionIDRIBSE'] = GetTransactionDetailsByTransactionIDRIBSE
globals()['GetTransactionDetailsByTransactionIDRIBSEC'] = GetTransactionDetailsByTransactionIDRIBSEC
globals()['GetTransactionDetailsByTransactionIDRIBSECGasPrice'] = GetTransactionDetailsByTransactionIDRIBSECGasPrice
globals()['GetTransactionDetailsByTransactionIDRIBSL'] = GetTransactionDetailsByTransactionIDRIBSL
from cryptoapis.model.get_transaction_details_by_transaction_idribs import GetTransactionDetailsByTransactionIDRIBS


class TestGetTransactionDetailsByTransactionIDRIBS(unittest.TestCase):
    """GetTransactionDetailsByTransactionIDRIBS unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGetTransactionDetailsByTransactionIDRIBS(self):
        """Test GetTransactionDetailsByTransactionIDRIBS"""
        # FIXME: construct object with mandatory attributes with example values
        # model = GetTransactionDetailsByTransactionIDRIBS()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
