"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import cryptoapis
from cryptoapis.model.list_xrp_ripple_transactions_by_block_hash_ri_fee import ListXRPRippleTransactionsByBlockHashRIFee
from cryptoapis.model.list_xrp_ripple_transactions_by_block_hash_ri_offer import ListXRPRippleTransactionsByBlockHashRIOffer
from cryptoapis.model.list_xrp_ripple_transactions_by_block_hash_ri_receive import ListXRPRippleTransactionsByBlockHashRIReceive
from cryptoapis.model.list_xrp_ripple_transactions_by_block_hash_ri_recipients import ListXRPRippleTransactionsByBlockHashRIRecipients
from cryptoapis.model.list_xrp_ripple_transactions_by_block_hash_ri_senders import ListXRPRippleTransactionsByBlockHashRISenders
from cryptoapis.model.list_xrp_ripple_transactions_by_block_hash_ri_value import ListXRPRippleTransactionsByBlockHashRIValue
globals()['ListXRPRippleTransactionsByBlockHashRIFee'] = ListXRPRippleTransactionsByBlockHashRIFee
globals()['ListXRPRippleTransactionsByBlockHashRIOffer'] = ListXRPRippleTransactionsByBlockHashRIOffer
globals()['ListXRPRippleTransactionsByBlockHashRIReceive'] = ListXRPRippleTransactionsByBlockHashRIReceive
globals()['ListXRPRippleTransactionsByBlockHashRIRecipients'] = ListXRPRippleTransactionsByBlockHashRIRecipients
globals()['ListXRPRippleTransactionsByBlockHashRISenders'] = ListXRPRippleTransactionsByBlockHashRISenders
globals()['ListXRPRippleTransactionsByBlockHashRIValue'] = ListXRPRippleTransactionsByBlockHashRIValue
from cryptoapis.model.list_xrp_ripple_transactions_by_block_hash_ri import ListXRPRippleTransactionsByBlockHashRI


class TestListXRPRippleTransactionsByBlockHashRI(unittest.TestCase):
    """ListXRPRippleTransactionsByBlockHashRI unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListXRPRippleTransactionsByBlockHashRI(self):
        """Test ListXRPRippleTransactionsByBlockHashRI"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListXRPRippleTransactionsByBlockHashRI()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
