"""
    CryptoAPIs

    Crypto APIs 2.0 is a complex and innovative infrastructure layer that radically simplifies the development of any Blockchain and Crypto related applications. Organized around REST, Crypto APIs 2.0 can assist both novice Bitcoin/Ethereum enthusiasts and crypto experts with the development of their blockchain applications. Crypto APIs 2.0 provides unified endpoints and data, raw data, automatic tokens and coins forwardings, callback functionalities, and much more.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: developers@cryptoapis.io
    Generated by: https://openapi-generator.tech
"""


import unittest

import cryptoapis
from cryptoapis.api.zilliqa_api import ZilliqaApi  # noqa: E501


class TestZilliqaApi(unittest.TestCase):
    """ZilliqaApi unit test stubs"""

    def setUp(self):
        self.api = ZilliqaApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_latest_mined_zilliqa_block(self):
        """Test case for get_latest_mined_zilliqa_block

        Get Latest Mined Zilliqa Block  # noqa: E501
        """
        pass

    def test_get_zilliqa_address_details(self):
        """Test case for get_zilliqa_address_details

        Get Zilliqa Address Details  # noqa: E501
        """
        pass

    def test_get_zilliqa_block_details_by_block_hash(self):
        """Test case for get_zilliqa_block_details_by_block_hash

        Get Zilliqa Block Details By Block Hash  # noqa: E501
        """
        pass

    def test_get_zilliqa_block_details_by_block_height(self):
        """Test case for get_zilliqa_block_details_by_block_height

        Get Zilliqa Block Details By Block Height  # noqa: E501
        """
        pass

    def test_get_zilliqa_transaction_details_by_transaction_id(self):
        """Test case for get_zilliqa_transaction_details_by_transaction_id

        Get Zilliqa Transaction Details by Transaction ID  # noqa: E501
        """
        pass

    def test_list_zilliqa_transactions_by_address(self):
        """Test case for list_zilliqa_transactions_by_address

        List Zilliqa Transactions by Address  # noqa: E501
        """
        pass

    def test_list_zilliqa_transactions_by_block_hash(self):
        """Test case for list_zilliqa_transactions_by_block_hash

        List Zilliqa Transactions By Block Hash  # noqa: E501
        """
        pass

    def test_list_zilliqa_transactions_by_block_height(self):
        """Test case for list_zilliqa_transactions_by_block_height

        List Zilliqa Transactions By Block Height  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
